# AnimeFLV API


> AnimeFLV is a python custom API for [animeflv.net](https://animeflv.net) a Spanish anime content website.

## Installation
For install with pip:
```bash
$ pip install animeflvV2
```

## API Documentation

#### Create animeflv api instance:
```python
>>> from animeflvV2 import AnimeFLV
>>> with AnimeFLV() as api:
>>>     # Do anything with api object
>>>    ...
```

#### Features
- [X] Get download links by episodes
- [X] Search
- [X] Get Video Servers
- [X] Get Anime Info
- [X] Get new releases (animes and episodes)

## License
[MIT](./LICENSE)

## Authors
+ [Julian Morera](https://github.com/JulianMorera07)
